@@ -1,6 +1,7 @@
 import json
 import numpy as np
 import datetime as dt
+import logging
 
 from .cdc_rules import civilstate, residence
 
@@ -8,7 +9,9 @@ from .cdc_rules import civilstate, residence
 class CDCParser:
     def __init__(self, raw_data):
         # str raw_data to json dict data
+        logging.info(f"cdc parser will transform raw_data to dictionary from {raw_data}")
         self.dict_data = json.loads(raw_data)
+        logging.info("cdc parser transformed correctly the raw_data to dictionary")
         # getting fields
         self.features = {}
         self.persona()
